package drawsheet.editors;


import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.util.ArrayList;
import java.util.Iterator;
import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IMarker;
import org.eclipse.core.resources.IResourceChangeEvent;
import org.eclipse.core.resources.IResourceChangeListener;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.QualifiedName;
import org.eclipse.jface.dialogs.ErrorDialog;
import org.eclipse.jface.text.IDocument;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.FocusEvent;
import org.eclipse.swt.events.FocusListener;
import org.eclipse.swt.events.MouseAdapter;
import org.eclipse.swt.events.MouseEvent;
import org.eclipse.swt.events.MouseMoveListener;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.graphics.GC;
import org.eclipse.swt.graphics.RGB;
import org.eclipse.swt.layout.RowData;
import org.eclipse.swt.layout.RowLayout;
import org.eclipse.swt.widgets.Canvas;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Label;
import org.eclipse.ui.*;
import org.eclipse.ui.editors.text.TextEditor;
import org.eclipse.ui.part.FileEditorInput;
import org.eclipse.ui.part.MultiPageEditorPart;
import org.eclipse.ui.ide.IDE;

import drawsheet.util.DrawSheetColorTable;

/**
 * An example showing how to create a multi-page editor.
 * This example has 3 pages:
 * <ul>
 * <li>page 0 contains a nested text editor.
 * <li>page 1 allows you to change the font used in page 2
 * <li>page 2 shows the words in page 0 in sorted order
 * </ul>
 */
public class DrawSheetEditor extends MultiPageEditorPart implements IResourceChangeListener{

	private TextEditor editor; //͌

	private Canvas canvas;
	int currentx, currenty;
	static int DRAWING;
	static GC gc;
	
	ArrayList lineList=new ArrayList();
	private IDocument doc;	
	
	int colorNumber; //ǋL
	static RGB[] rgbs=DrawSheetColorTable.getRGBs(); //ǋL
	
	private static final String OWNER_PROPERTY = "OWNER";
	private static final String OWNER_TITLE = "쐬ҁF";
	private static final String DEFAULT_OWNER = "sȃI[i[";
	private Label ownerLabel;
	

	/**
	 * Creates a multi-page editor example.
	 */
	public DrawSheetEditor() {
		super();
		ResourcesPlugin.getWorkspace().addResourceChangeListener(this);
	}
	/**
	 * Creates page 0 of the multi-page editor,
	 * which contains a text editor.
	 */
	void createPage0() {
		try {
			editor = new TextEditor();
			
			//ǉ	
			try{
				IFile ieditorFile=((FileEditorInput)getEditorInput())
				.getFile();//ҏWĂt@C𓾂
				
				File file=ieditorFile.getLocation().toFile();
				//java.io.FileIuWFNgɕϊ
				
				//悭t@C̓ǂݏo
				BufferedReader br= new BufferedReader(
					new FileReader(file)
				);
					
				while(br.ready()){
					
					String linedots=br.readLine();
					//eLXgf[^sǂ
						
					String[] dotstrs=linedots.split(",");
					//J}؂4̗vfɕ
						
					int[] dots=new int[5];
					for(int i=0;i<5;i++){
						dots[i]=Integer.parseInt(dotstrs[i]);
						
					}				
					
					lineList.add(dots);//zArrayListɊi[
						
				}
					
			}
			catch(Exception e){
			}
			//܂
			
			int index = addPage(editor, getEditorInput());
			setPageText(index, editor.getTitle());
		} catch (PartInitException e) {
			ErrorDialog.openError(
				getSite().getShell(),
				"Error creating nested text editor",
				null,
				e.getStatus());
		}
	}
	/**
	 * Creates page 1 of the multi-page editor,
	 * which allows you to change the font used in page 2.
	 */
	void createPage1() {

		Composite composite = new Composite(getContainer(), SWT.NONE);
		
		RowLayout rl = new RowLayout();
		composite.setLayout(rl);
		
		canvas=new Canvas(composite, SWT.NONE);
		canvas.setLayoutData(new RowData(300,200));
		
		Color color= new Color(Display.getCurrent(), new RGB(225,225,255));
		canvas.setBackground(color);
		
		ownerLabel=new Label(composite, SWT.WRAP);
		ownerLabel.setLayoutData(new RowData(200,60));
		restoreLabel();
		
		gc=new GC(canvas);
		
		DRAWING=0;
		
		colorNumber=0;//ꂪVR[h
		
		canvas.addMouseListener(
				new MouseAdapter(){					
					public void mouseDown(MouseEvent me){						
						if(DRAWING==0){						
						DRAWING=1;
						currentx=me.x;
						currenty=me.y;						
						}						
					}
					public void mouseUp(MouseEvent me){						
						if(DRAWING==1){
							DRAWING=0;
							lineToDoc(); //ǋL
						}
					}					
				}
			);
		
		canvas.addMouseMoveListener(new MouseMoveListener(){			
			public void mouseMove(MouseEvent me){			
				if(DRAWING==1){	 //L̏ꍇ
								
					int lastx=currentx; //O̍Wޔ
					int lasty=currenty;
							
					currentx=me.x;//̍W擾
					currenty=me.y;
					
					Color fcolor=new Color(Display.getCurrent(),
							rgbs[colorNumber]
						);
					gc.setForeground(fcolor);
						
					gc.drawLine(lastx, lasty, currentx, currenty);
					//O̍Wƍ̍W̊Ԃɐ
					
					//
					
						lineList.add(new int[]{
								colorNumber,lastx, lasty,currentx, currenty
						});
					
					//܂Œǉ
							
				}
			}
		});
		
		canvas.addFocusListener(new FocusListener(){

			public void focusGained(FocusEvent e) {
				// TODO ꂽ\bhEX^u
				
				restoreCanvas();
				
			}

			public void focusLost(FocusEvent e) {
				// TODO ꂽ\bhEX^u
				
			}});

		
		int index = addPage(composite);
		setPageText(index, "Canvas");
	}
	/**
	 * Creates page 2 of the multi-page editor,
	 * which shows the sorted text.
	 */

	/**
	 * Creates the pages of the multi-page editor.
	 */
	protected void createPages() {
		createPage0();
		createPage1();
		setActivePage(1); 
			//NɊJy[W̐ݒ
	}
	/**
	 * The <code>MultiPageEditorPart</code> implementation of this 
	 * <code>IWorkbenchPart</code> method disposes all nested editors.
	 * Subclasses may extend.
	 */
	public void dispose() {
		ResourcesPlugin.getWorkspace().removeResourceChangeListener(this);
		super.dispose();
	}
	/**
	 * Saves the multi-page editor's document.
	 */
	public void doSave(IProgressMonitor monitor) {
		getEditor(0).doSave(monitor);
	}
	/**
	 * Saves the multi-page editor's document as another file.
	 * Also updates the text for page 0's tab, and updates this multi-page editor's input
	 * to correspond to the nested editor's.
	 */
	public void doSaveAs() {
		IEditorPart editor = getEditor(0);
		editor.doSaveAs();
		setPageText(0, editor.getTitle());
		setInput(editor.getEditorInput());
	}
	/* (non-Javadoc)
	 * Method declared on IEditorPart
	 */
	public void gotoMarker(IMarker marker) {
		setActivePage(0);
		IDE.gotoMarker(getEditor(0), marker);
	}
	/**
	 * The <code>MultiPageEditorExample</code> implementation of this method
	 * checks that the input is an instance of <code>IFileEditorInput</code>.
	 */
	public void init(IEditorSite site, IEditorInput editorInput)
		throws PartInitException {
		if (!(editorInput instanceof IFileEditorInput))
			throw new PartInitException("Invalid Input: Must be IFileEditorInput");
		super.init(site, editorInput);
	}
	/* (non-Javadoc)
	 * Method declared on IEditorPart.
	 */
	public boolean isSaveAsAllowed() {
		return true;
	}
	/**
	 * Calculates the contents of page 2 when the it is activated.
	 */
	protected void pageChange(int newPageIndex) {
		super.pageChange(newPageIndex);
		if (newPageIndex == 0) { //y[W2y[W0ɂ
			
			lineToDoc();
					
			}
		else if (newPageIndex == 1) {
			
		
		
	}//܂
		
	}
	/**
	 * Closes all project files on project close.
	 */
	public void resourceChanged(final IResourceChangeEvent event){
		if(event.getType() == IResourceChangeEvent.PRE_CLOSE){
			Display.getDefault().asyncExec(new Runnable(){
				public void run(){
					IWorkbenchPage[] pages = getSite().getWorkbenchWindow().getPages();
					for (int i = 0; i<pages.length; i++){
						if(((FileEditorInput)editor.getEditorInput()).getFile().getProject().equals(event.getResource())){
							IEditorPart editorPart = pages[i].findEditor(editor.getEditorInput());
							pages[i].closeEditor(editorPart,true);
						}
					}
				}            
			});
		}
	}
	
	
	public void lineToDoc(){
		
	doc=editor.getDocumentProvider().getDocument( 
			getEditorInput()
		);
			
	String textstr=new String();
			
	Iterator it=lineList.iterator();
		
	while(it.hasNext()){
				
		int[]dots=(int[])it.next();
		for(int i=0;i<4;i++){
			textstr += Integer.toString(dots[i])+",";
		}
		textstr += dots[4]+"\n";
				
	}
			
	doc.set(textstr); 
			
	}
	
	public void restoreCanvas(){

		canvas.update();
		
		gc=new GC(canvas);
			
		Iterator it= lineList.iterator();
			while(it.hasNext()){
				
			int[] dots=(int[])it.next();
			
			//ŏ̗vf͐Ff[^
			Color fcolor=new Color(Display.getCurrent(),
					rgbs[dots[0]]
				);
			gc.setForeground(fcolor);
			
		//̗vfWf[^
			gc.drawLine(
				dots[1],dots[2],dots[3],dots[4]
			);
			
		}
			restoreLabel();
	}
	
	public void restoreLabel(){
		try {			
			IFile ieditorFile=((FileEditorInput)getEditorInput())
			.getFile();
			String owner =
				ieditorFile.getPersistentProperty(
					new QualifiedName("", OWNER_PROPERTY)
					);
				
			if (owner==null||owner.length()<=0){
				owner=DEFAULT_OWNER;
			}
				
			ownerLabel.setText(
					OWNER_TITLE+owner
					);
		} catch (CoreException e) {
			ownerLabel.setText(OWNER_TITLE+DEFAULT_OWNER);
		}
		
	}
	
	public void clearlineList(){
		lineList=new ArrayList();
	}
	
	public void clearCanvas(){
		canvas.redraw();

	}
	
	public void setColorNumber(int number){
		
	colorNumber=number;
		
}

}
