package drawsheet.views;


import java.net.URL;

import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.part.*;
import org.eclipse.core.runtime.Path;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.jface.viewers.*;
import org.eclipse.swt.graphics.Image;
import org.eclipse.jface.action.*;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.ui.*;
import org.eclipse.swt.SWT;

import drawsheet.DrawsheetPlugin;
import drawsheet.editors.DrawSheetEditor;
import drawsheet.util.DrawSheetColorTable;


/**
 * This sample class demonstrates how to plug-in a new
 * workbench view. The view shows data obtained from the
 * model. The sample creates a dummy model on the fly,
 * but a real implementation would connect to the model
 * available either in this or another plug-in (e.g. the workspace).
 * The view is connected to the model using a content provider.
 * <p>
 * The view uses a label provider to define how model
 * objects should be presented in the view. Each
 * view can present the same model objects using
 * different labels and icons, if needed. Alternatively,
 * a single label provider can be shared between views
 * in order to ensure that objects of the same type are
 * presented in the same way everywhere.
 * <p>
 */

public class PaletteView extends ViewPart {
	private TableViewer viewer;
	private Action selectAction;
	private Action doubleClickAction;

	static String[] colorNames=
		DrawSheetColorTable.getColorNames(); //擾̂ς
	
	/*
	 * The content provider class is responsible for
	 * providing objects to the view. It can wrap
	 * existing objects in adapters or simply return
	 * objects as-is. These objects may be sensitive
	 * to the current input of the view, or ignore
	 * it and always show the same content 
	 * (like Task List, for example).
	 */
	 
	class ViewContentProvider implements IStructuredContentProvider {
		public void inputChanged(Viewer v, Object oldInput, Object newInput) {
		}
		public void dispose() {
		}
		public Object[] getElements(Object parent) {
			return PaletteView.colorNames;
		}
	}
	class ViewLabelProvider extends LabelProvider implements ITableLabelProvider {
		public String getColumnText(Object obj, int index) {
			return getText(obj);
		}
		public Image getColumnImage(Object obj, int index) {
			return getImage(obj);
		}
		public Image getImage(Object obj) {
						
			DrawsheetPlugin dp= DrawsheetPlugin.getDefault();
			
			String filePathName="icons/"+
			 getText(obj).toLowerCase()+".gif"; //XguBlackvȂublack.gifvɂȂ
			
			URL url=dp.find(new Path(filePathName));
				
			ImageDescriptor descriptor=ImageDescriptor.createFromURL(url);
			Image img=descriptor.createImage();//Imageɂ
				
			return img;
				
		}
	}

	/**
	 * The constructor.
	 */
	public PaletteView() {
	}

	/**
	 * This is a callback that will allow us
	 * to create the viewer and initialize it.
	 */
	public void createPartControl(Composite parent) {
		viewer = new TableViewer(parent, SWT.MULTI | SWT.H_SCROLL | SWT.V_SCROLL);
		viewer.setContentProvider(new ViewContentProvider());
		viewer.setLabelProvider(new ViewLabelProvider());
		viewer.setInput(getViewSite());
		makeActions();
		hookDoubleClickAction();
		contributeToActionBars();
	}


	private void contributeToActionBars() {
		IActionBars bars = getViewSite().getActionBars();
		fillLocalPullDown(bars.getMenuManager());
		fillLocalToolBar(bars.getToolBarManager());
	}

	private void fillLocalPullDown(IMenuManager manager) {
		manager.add(selectAction);
		
		
	}

	
	private void fillLocalToolBar(IToolBarManager manager) {
		manager.add(selectAction);
		
	}

	private void makeActions() {
		selectAction = new Action() {
			public void run() {
					
				ISelection selection = viewer.getSelection();
				Object obj = ((IStructuredSelection)selection).getFirstElement();
					
				for(int i=0; i<colorNames.length; i++){
						
					if(colorNames[i].equals(obj.toString())){ 
						selectColor(i);
					}
				}
					
			}//run\bh̏I
		}; //selectAction̒`I
	
	
		selectAction.setText("Select");
		selectAction.setToolTipText("F̑I");
		
		DrawsheetPlugin dp= DrawsheetPlugin.getDefault();
		String filePathName="icons/palette.gif";
		URL url=dp.find(new Path(filePathName));
				
		ImageDescriptor descriptor=ImageDescriptor.createFromURL(url);
		selectAction.setImageDescriptor(descriptor);	
		
		doubleClickAction = new Action() {
			public void run() {
				ISelection selection = viewer.getSelection();
				Object obj = ((IStructuredSelection)selection).getFirstElement();
				
				for(int i=0; i<colorNames.length; i++){
					
					if(colorNames[i].equals(obj.toString())){ //r[̎擾f[^Ff[^Əƍ
						selectColor(i);//vFɂ
					}
				}
			}
		};
	}

	private void hookDoubleClickAction() {
		viewer.addDoubleClickListener(new IDoubleClickListener() {
			public void doubleClick(DoubleClickEvent event) {
				doubleClickAction.run();
			}
		});
	}
	private void showMessage(String message) {
		MessageDialog.openInformation(
			viewer.getControl().getShell(),
			"Palette View",
			message);
	}
	
	
	private void selectColor(int index) {
		
		DrawSheetEditor currenteditor=
			(DrawSheetEditor)getSite().getPage().getActiveEditor();
			
		currenteditor.setColorNumber(index);
		
	
	}

	/**
	 * Passing the focus request to the viewer's control.
	 */
	public void setFocus() {
		viewer.getControl().setFocus();
	}
}