package drawsheet.editors;

import java.net.URL;

import org.eclipse.core.runtime.Path;
import org.eclipse.jface.action.*;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.ui.IActionBars;
import org.eclipse.ui.IEditorPart;
import org.eclipse.ui.IWorkbenchActionConstants;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.actions.ActionFactory;
import org.eclipse.ui.ide.IDE;
import org.eclipse.ui.ide.IDEActionFactory;
import org.eclipse.ui.part.MultiPageEditorActionBarContributor;
import org.eclipse.ui.texteditor.ITextEditor;
import org.eclipse.ui.texteditor.ITextEditorActionConstants;

import drawsheet.DrawsheetPlugin;

/**
 * Manages the installation/deinstallation of global actions for multi-page editors.
 * Responsible for the redirection of global actions to the active editor.
 * Multi-page contributor replaces the contributors for the individual editors in the multi-page editor.
 */
public class DrawSheetEditorContributor extends MultiPageEditorActionBarContributor {
	
	private IEditorPart activeEditorPart;
	private Action clearAction;
	private Action restoreAction; //ǋL

	/**
	 * Creates a multi-page contributor.
	 */
	public DrawSheetEditorContributor() {
		super();
		createActions();
	}
	/**
	 * Returns the action registed with the given text editor.
	 * @return IAction or null if editor is null.
	 */
	protected IAction getAction(ITextEditor editor, String actionID) {
		return (editor == null ? null : editor.getAction(actionID));
	}
	/* (non-JavaDoc)
	 * Method declared in AbstractMultiPageEditorActionBarContributor.
	 */

	public void setActivePage(IEditorPart part) {
		if (activeEditorPart == part)
			return;

		activeEditorPart = part;

		IActionBars actionBars = getActionBars();
		if (actionBars != null) {

			ITextEditor editor = (part instanceof ITextEditor) ? (ITextEditor) part : null;

			actionBars.setGlobalActionHandler(
				ActionFactory.DELETE.getId(),
				getAction(editor, ITextEditorActionConstants.DELETE));
			actionBars.setGlobalActionHandler(
				ActionFactory.UNDO.getId(),
				getAction(editor, ITextEditorActionConstants.UNDO));
			actionBars.setGlobalActionHandler(
				ActionFactory.REDO.getId(),
				getAction(editor, ITextEditorActionConstants.REDO));
			actionBars.setGlobalActionHandler(
				ActionFactory.CUT.getId(),
				getAction(editor, ITextEditorActionConstants.CUT));
			actionBars.setGlobalActionHandler(
				ActionFactory.COPY.getId(),
				getAction(editor, ITextEditorActionConstants.COPY));
			actionBars.setGlobalActionHandler(
				ActionFactory.PASTE.getId(),
				getAction(editor, ITextEditorActionConstants.PASTE));
			actionBars.setGlobalActionHandler(
				ActionFactory.SELECT_ALL.getId(),
				getAction(editor, ITextEditorActionConstants.SELECT_ALL));
			actionBars.setGlobalActionHandler(
				ActionFactory.FIND.getId(),
				getAction(editor, ITextEditorActionConstants.FIND));
			actionBars.setGlobalActionHandler(
				IDEActionFactory.BOOKMARK.getId(),
				getAction(editor, IDEActionFactory.BOOKMARK.getId()));
			actionBars.updateActionBars();
		}
	}
	private void createActions() {
		clearAction = new Action() {
			public void run() {
				 //ҏW̃GfB^擾
				DrawSheetEditor currenteditor=
					(DrawSheetEditor)getPage().getActiveEditor();
					
				currenteditor.clearlineList();
				currenteditor.clearCanvas();
			}
		};
		clearAction.setText("S");
		clearAction.setToolTipText("GNA");
		clearAction.setImageDescriptor(		
				getIconImageDescriptor("nofrog.gif")
		);
		
		restoreAction = new Action() {
			public void run() {
				DrawSheetEditor currenteditor=
					(DrawSheetEditor)getPage().getActiveEditor();
				
				currenteditor.restoreCanvas();
			}
		};
		restoreAction.setText("");
		restoreAction.setToolTipText("G𕜌");
		restoreAction.setImageDescriptor(		
				getIconImageDescriptor("frog.gif")
			);
		
		//restoreAction.setImageDescriptorEEEƂLq́C܂Ȃ
	}
	public void contributeToMenu(IMenuManager manager) {
		IMenuManager menu = new MenuManager("DrawSheet");
		manager.prependToGroup(IWorkbenchActionConstants.MB_ADDITIONS, menu);
		menu.add(clearAction);
		menu.add(restoreAction);
	}
	public void contributeToToolBar(IToolBarManager manager) {
		manager.add(new Separator());
		manager.add(clearAction);
		manager.add(restoreAction);
	}
	
	public ImageDescriptor getIconImageDescriptor(String filename){
		
		DrawsheetPlugin dp= DrawsheetPlugin.getDefault();
		String filePathName="icons/"+filename; 
			//vOCCXg[ӏ̑΃pX
		URL url=dp.find(new Path(filePathName));
		
		ImageDescriptor descriptor=ImageDescriptor.createFromURL(url);
		return descriptor;
		
	}
}
