package ppagethree.properties;

import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.QualifiedName;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;
import org.eclipse.ui.dialogs.PropertyPage;

public class TotalPropertyPage extends PropertyPage {

	private static final String CONT_TITLE = "e:";
	private static final int TEXT_WIDTH =60;
	
	private static final String CAT_TITLE = "JeS:";
	private static final String CAT_PROPERTY = "CATEGORY";
	private static final String DEFAULT_CAT = "Eclipse";

	private Combo catCombo;
	
	private static final String[] CAT_ITEMS=
	{"Eclipse","NetBeans","Other"};


	/**
	 * Constructor for SamplePropertyPage.
	 */
	public TotalPropertyPage() {
		super();
	}

	private void addFirstSection(Composite parent) {
		Composite composite = createDefaultComposite(parent);


		Label catLabel = new Label(composite, SWT.NONE);
		catLabel.setText(CAT_TITLE);
		
		catCombo= new Combo(composite, SWT.DROP_DOWN);
		catCombo.setItems(CAT_ITEMS);
		
		// Populate owner text field
		try {
			String indexStr =
				((IResource) getElement()).getPersistentProperty(
					new QualifiedName("", CAT_PROPERTY));
			
			if(indexStr!=null&&indexStr.length()>0){
				catCombo.select(Integer.parseInt(indexStr));
			}
			else{
				catCombo.select(0);
				
			}
			
		} catch (CoreException e) {
			catCombo.select(0);
		}
	}

	private void addSeparator(Composite parent) {
		Label separator = new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
		GridData gridData = new GridData();
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		separator.setLayoutData(gridData);
	}

	private void addSecondSection(Composite parent) {
		Composite composite = createDefaultComposite(parent);

		Label contLabel = new Label(composite, SWT.NONE);
		contLabel.setText(CONT_TITLE);

		Text valueText = new Text(composite, SWT.WRAP |SWT.MULTI |SWT.READ_ONLY);
		GridData gd = new GridData();
		gd.widthHint = convertWidthInCharsToPixels(TEXT_WIDTH);
		valueText.setLayoutData(gd);
		
		String filename=
			((IResource) getElement()).getLocation().toString();
		valueText.setText(		
				readFile(filename)
		);
		
	}
	
	public String readFile(String filename) {

		String content = new String();

		try {
			BufferedReader br = new BufferedReader(new FileReader(filename));

			while (br.ready()) {
				content += br.readLine();
				int count = content.length();
				if (count > 50) {
					content = content.substring(0, 49) + "...";
					break;
				}

			}
		} catch (FileNotFoundException fe) {

			content = "t@C݂܂";
		} catch (IOException ioe) {
			content = "I/OG[";
		}

		return content;
	}

	
	


	/**
	 * @see PreferencePage#createContents(Composite)
	 */
	protected Control createContents(Composite parent) {
		Composite composite = new Composite(parent, SWT.NONE);
		GridLayout layout = new GridLayout();
		composite.setLayout(layout);
		GridData data = new GridData(GridData.FILL);
		data.grabExcessHorizontalSpace = true;
		composite.setLayoutData(data);

		addFirstSection(composite);
		addSeparator(composite);
		addSecondSection(composite);
		return composite;
	}

	private Composite createDefaultComposite(Composite parent) {
		Composite composite = new Composite(parent, SWT.NULL);
		GridLayout layout = new GridLayout();
		layout.numColumns = 2;
		composite.setLayout(layout);

		GridData data = new GridData();
		data.verticalAlignment = GridData.FILL;
		data.horizontalAlignment = GridData.FILL;
		composite.setLayoutData(data);

		return composite;
	}

	protected void performDefaults() {
		// Populate the owner text field with the default value
		catCombo.select(0);;
	}
	
	public boolean performOk() {
		// store the value in the owner text field
		try {
			((IResource) getElement()).setPersistentProperty(
				new QualifiedName("", CAT_PROPERTY),
				
				Integer.toString(catCombo.getSelectionIndex()));
			
		} catch (CoreException e) {
			return false;
		}
		return true;
	}

}