package ppagetwo.properties;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.QualifiedName;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Label;
import org.eclipse.ui.dialogs.PropertyPage;

public class CategoryPropertyPage extends PropertyPage {

	private static final String CAT_TITLE = "JeS:";
	private static final String CAT_PROPERTY = "CATEGORY";
	private static final String DEFAULT_CAT = "Eclipse";

	private Combo catCombo;
	
	private static final String[] CAT_ITEMS=
	{"Eclipse","NetBeans","Other"};


	/**
	 * Constructor for SamplePropertyPage.
	 */
	public CategoryPropertyPage() {
		super();
	}

	private void addFirstSection(Composite parent) {
		Composite composite = createDefaultComposite(parent);

		Label dummyLabel = new Label(composite, SWT.NONE);
		dummyLabel.setText("͗Kp̃eLXgt@Cł");	
	}

	private void addSeparator(Composite parent) {
		Label separator = new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
		GridData gridData = new GridData();
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		separator.setLayoutData(gridData);
	}

	private void addSecondSection(Composite parent) {
		Composite composite = createDefaultComposite(parent);

		Label catLabel = new Label(composite, SWT.NONE);
		catLabel.setText(CAT_TITLE);
			
		catCombo= new Combo(composite, SWT.DROP_DOWN);
		catCombo.setItems(CAT_ITEMS);
			
		try {
			String indexStr =
				((IResource) getElement()).getPersistentProperty(
					new QualifiedName("", CAT_PROPERTY));
				
			if(indexStr!=null&&indexStr.length()>0){
				catCombo.select(Integer.parseInt(indexStr));
			}
			else{
				catCombo.select(0);
					
			}
				
		} catch (CoreException e) {
			catCombo.select(0);
		}
	}

	/**
	 * @see PreferencePage#createContents(Composite)
	 */
	protected Control createContents(Composite parent) {
		Composite composite = new Composite(parent, SWT.NONE);
		GridLayout layout = new GridLayout();
		composite.setLayout(layout);
		GridData data = new GridData(GridData.FILL);
		data.grabExcessHorizontalSpace = true;
		composite.setLayoutData(data);

		addFirstSection(composite);
		addSeparator(composite);
		addSecondSection(composite);
		return composite;
	}

	private Composite createDefaultComposite(Composite parent) {
		Composite composite = new Composite(parent, SWT.NULL);
		GridLayout layout = new GridLayout();
		layout.numColumns = 2;
		composite.setLayout(layout);

		GridData data = new GridData();
		data.verticalAlignment = GridData.FILL;
		data.horizontalAlignment = GridData.FILL;
		composite.setLayoutData(data);

		return composite;
	}

	protected void performDefaults() {
		// Populate the owner text field with the default value
		catCombo.select(0);
	}
	
	public boolean performOk() {
		// store the value in the owner text field
		try {
			((IResource) getElement()).setPersistentProperty(
				new QualifiedName("", CAT_PROPERTY),
					
				Integer.toString(catCombo.getSelectionIndex()));
				
		} catch (CoreException e) {
			return false;
		}
		return true;
	}

}